@@ -6,11 +6,11 @@ reading and writing values in the process memory.
 """
 
 __author__ = "Jean Loui Bernard Silva de Jesus"
-__version__ = "1.4.5"
+__version__ = "1.4.10"
 
 import sys
 
 if "win" not in sys.platform:
     raise OSError("Only Windows OS is currently supported.")
 
-from .open_process import OpenProcess, ProcessOperationsEnum
+from .open_process import OpenProcess, ProcessOperationsEnum, ScanTypesEnum
